cmdprovider

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildProviderCommands

func BuildProviderCommands(kind string, deps cmdutil.Deps) []*cobra.Command

BuildProviderCommands returns the "issues" and "issue" cobra commands that use the given provider kind for resolution.

func ClearConfirmCode

func ClearConfirmCode(key string)

ClearConfirmCode removes the temp file after successful deletion.

func ConfirmPath

func ConfirmPath(key string) string

ConfirmPath returns the file path for a confirmation code.

func GenerateConfirmCode

func GenerateConfirmCode(key string) (int, error)

GenerateConfirmCode creates a random 6-digit code, writes it to a file, returns it.

func PrintStatusesTable

func PrintStatusesTable(out io.Writer, statuses []tracker.Status) error

PrintStatusesTable prints statuses as a table.

func RunAddComment

func RunAddComment(ctx context.Context, p tracker.Provider, out io.Writer, key, body string) error

RunAddComment adds a comment to an issue.

func RunCreateIssue

func RunCreateIssue(ctx context.Context, p tracker.Provider, out io.Writer, project, typ, title, description string) error

RunCreateIssue creates a new issue.

func RunDeleteIssue

func RunDeleteIssue(ctx context.Context, p tracker.Provider, out io.Writer, key string, confirm int) error

RunDeleteIssue deletes an issue after confirmation.

func RunEditIssue

func RunEditIssue(ctx context.Context, p tracker.Provider, out io.Writer, key string, opts tracker.EditOptions) error

RunEditIssue edits an issue's title and/or description.

func RunGetIssue

func RunGetIssue(ctx context.Context, p tracker.Provider, out io.Writer, key string) error

RunGetIssue retrieves and prints a single issue.

func RunListComments

func RunListComments(ctx context.Context, p tracker.Provider, out io.Writer, key string) error

RunListComments lists comments on an issue.

func RunListIssues

func RunListIssues(ctx context.Context, p tracker.Provider, out io.Writer, project string, all, table bool) error

RunListIssues lists issues for a project.

func RunListStatuses

func RunListStatuses(ctx context.Context, p tracker.Provider, out io.Writer, key string, table bool) error

RunListStatuses lists available statuses for an issue.

func RunSetStatus

func RunSetStatus(ctx context.Context, p tracker.Provider, out io.Writer, key, status string) error

RunSetStatus sets an issue's status.

func RunStartIssue

func RunStartIssue(ctx context.Context, p tracker.Provider, out io.Writer, key string) error

RunStartIssue transitions an issue and assigns to the current user.

Types

This section is empty.

Jump to